@@ -1,9 +1,7 @@
-#!/bin/sh
+#!/bin/sh -ex
 
 source VERSION
 
-set -e
-
 make distclean || true
 
 cd ..
